one_button class

Inheritance

Constructors

one_button({Key? key, required bool border, Widget? widget, BorderStyle? borderStyle, double? borderwidth, Color? buttonColor, String? title, Function? onClickCallBack, Color? borderradiusColor, double? buttonradius, TextStyle? style, double? buttonheight, double? buttonwidth})

Properties

border ↔ bool
getter/setter pair
borderradiusColor ↔ Color?
getter/setter pair
borderStyle ↔ BorderStyle?
getter/setter pair
borderwidth ↔ double?
getter/setter pair
buttonColor ↔ Color?
getter/setter pair
buttonheight ↔ double?
getter/setter pair
buttonradius ↔ double?
getter/setter pair
buttonwidth ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onClickCallBack ↔ Function?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
getter/setter pair
title ↔ String?
getter/setter pair
widget ↔ Widget?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<one_button>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited